@@ -271,10 +271,17 @@ public class UnsynchronizedBufferedReader extends UnsynchronizedReader {
      */
     @Override
     public int read(final char[] buffer, int offset, final int length) throws IOException {
+        /*
+         * First throw on a closed reader, then check the parameters.
+         *
+         * This behavior is not specified in the Javadoc, but is followed by most readers in java.io.
+         */
         checkOpen();
-        if (offset < 0 || offset > buffer.length - length || length < 0) {
-            throw new IndexOutOfBoundsException();
+        IOUtils.checkFromIndexSize(buffer, offset, length);
+        if (length == 0) {
+            return 0;
         }
+
         int outstanding = length;
         while (outstanding > 0) {
 
